/*
 * Author: Dr. Chris Taylor
 * Date: 01/16/2009
 */

package edu.msoe.se1021.YOURLOGIN;

import java.util.Random;
import edu.msoe.se1021.audio.WavPlayer;

/**
 * Represents a chicken.
 * @version 1.1 12/19/2009
 * @author t a y l o r@msoe.edu
 * @see Vocalize
 */
public class Chicken extends Livestock implements Vocalize {
	
	/**
	 * Indicates that the chicken is an egg layer (true)
	 * or a broiler (false).
	 */
	private boolean layer;
	

	/**
	 * Maximum age for a chicken.
	 */
	public static final int MAX_AGE = 5;
	
	/**
	 * Maximum weight for a chicken.
	 */
	public static final int MAX_WEIGHT = 10;

	/**
	 * Minimum weight for a chicken.
	 */
	public static final int MIN_WEIGHT = 1;

	/**
	 * Creates a chicken with randomized attributes.
	 */
	public Chicken() {
		this(numPicker.nextInt(MAX_AGE),
				numPicker.nextBoolean(), 
				numPicker.nextInt(MAX_WEIGHT-MIN_WEIGHT)+MIN_WEIGHT);
	}

	/**
	 * Creates a chicken with specified attributes
	 * @param age Age of the chicken
	 * @param layer True if the chicken is bred to lay eggs
	 * @param weight Weight of the chicken in pounds
	 * @throws IllegalArgumentException if attributes are outside of acceptable limits
	 */
	public Chicken(int age, boolean layer, int weight) {
		if(0<=age && age<MAX_AGE) {
			this.age = age;
		} else {
			throw new IllegalArgumentException("Illegal Argument: age must be between 0 and " 
					+ MAX_AGE);
		}
		this.layer = layer;
		if(MIN_WEIGHT<=weight && weight<MAX_WEIGHT) {
			this.weightInPounds = weight;
		} else {
			throw new IllegalArgumentException("Illegal Argument: weight must be between "
					+ MIN_WEIGHT + " and " + MAX_WEIGHT);
		}
	}
	
	/**
	 * The string representation of a chicken.
	 * @return String representation of the object
	 */
	public String toString() {
		return "A " + age + " year old, " + (layer ? "egg layer" : "broiler") + " weighing " + weightInPounds + " pounds";
	}
	
	@Override
	/**
	 * Cause object to vocalize (make its sound).
	 */
	public void vocalize() {
		WavPlayer player = new WavPlayer("cluck.wav");
		player.play();
	}

}
