/*
 * Author: Dr. Chris Taylor
 * Date: 01/16/2009
 */

package edu.msoe.se1021.YOURLOGIN;

import java.util.Random;
import edu.msoe.se1021.audio.WavPlayer;

/**
 * Represents a dog.
 * @version 1.1 12/19/2009
 * @author t a y l o r@msoe.edu
 * @see Vocalize
 */
public class Dog extends Livestock implements Vocalize {
	
	/**
	 * The height of the dog in inches.
	 */
	private double heightInInches;
	
	/**
	 * Maximum age for a dog.
	 */
	public static final int MAX_AGE = 12;
	
	/**
	 * Maximum height for a dog.
	 */
	public static final int MAX_HEIGHT = 40;

	/**
	 * Minimum height for a dog.
	 */
	public static final int MIN_HEIGHT = 5;

	/**
	 * Maximum weight for a dog.
	 */
	public static final int MAX_WEIGHT = 240;

	/**
	 * Minimum weight for a dog.
	 */
	public static final int MIN_WEIGHT = 5;

	/**
	 * Creates a dog with randomized attributes.
	 */
	public Dog() {
		this(numPicker.nextInt(MAX_AGE), 
				numPicker.nextInt(MAX_HEIGHT-MIN_HEIGHT) + MIN_HEIGHT, 
				numPicker.nextInt(MAX_WEIGHT-MIN_WEIGHT) + MIN_WEIGHT);
	}

	/**
	 * Creates a dog with specified attributes
	 * @param age Age of the dog
	 * @param height Height of the dog in inches
	 * @param weight Weight of the dog in pounds
	 * @throws IllegalArgumentException if attributes are outside of acceptable limits
	 */
	public Dog(int age, int height, int weight) {
		if(0<=age && age<=MAX_AGE) {
			this.age = age;
		} else {
			throw new IllegalArgumentException("Illegal Argument: age must be between 0 and " 
					+ MAX_AGE);
		}
		if(MIN_HEIGHT<=height && height<=MAX_HEIGHT) {
			this.heightInInches = height;
		} else {
			throw new IllegalArgumentException("Illegal Argument: height must be between " 
					+ MIN_HEIGHT + " and " + MAX_HEIGHT);
		}
		if(MIN_WEIGHT<=weight && weight<=MAX_WEIGHT) {
			this.weightInPounds = weight;
		} else {
			throw new IllegalArgumentException("Illegal Argument: weight must be between "
					+ MIN_WEIGHT + " and " + MAX_WEIGHT);
		}
	}
	
	/**
	 * The string representation of a dog.
	 * @return String representation of the object
	 */
	public String toString() {
		return "A " + age + " year old, " + heightInInches + " inch tall dog weighing " + weightInPounds + " pounds";
	}
	
	@Override
	/**
	 * Cause object to vocalize (make its sound).
	 */
	public void vocalize() {
		WavPlayer player = new WavPlayer("bark.wav");
		player.play();
	}

}
