/*
 * Author: Dr. Chris Taylor
 * Date: 01/16/2009
 */

package edu.msoe.se1021.YOURLOGIN;

import java.util.Random;
import edu.msoe.se1021.audio.WavPlayer;

/**
 * Represents a sheep.
 * @version 1.1 12/19/2009
 * @author t a y l o r@msoe.edu
 * @see Vocalize
 */
public class Sheep extends Livestock implements Vocalize {
	
	/**
	 * The height of the sheep in inches.
	 */
	private double heightInInches;
	
	/**
	 * Indicates whether the sheep has been shorn (wool removed)
	 * recently (true if yes).
	 */
	private boolean shornRecently;
	
	/**
	 * Maximum age for a sheep.
	 */
	public static final int MAX_AGE = 12;
	
	/**
	 * Maximum height for a sheep.
	 */
	public static final int MAX_HEIGHT = 30;

	/**
	 * Minimum height for a sheep.
	 */
	public static final int MIN_HEIGHT = 5;

	/**
	 * Maximum weight for a sheep.
	 */
	public static final int MAX_WEIGHT = 200;

	/**
	 * Minimum weight for a sheep.
	 */
	public static final int MIN_WEIGHT = 10;

	/**
	 * Creates a sheep with randomized attributes.
	 */
	public Sheep() {
		this(numPicker.nextInt(MAX_AGE),
				numPicker.nextBoolean(),
				numPicker.nextInt(MAX_HEIGHT-MIN_HEIGHT) + MIN_HEIGHT, 
				numPicker.nextInt(MAX_WEIGHT-MIN_WEIGHT) + MIN_WEIGHT);
	}

	/**
	 * Creates a sheep with specified attributes
	 * @param age Age of the sheep
	 * @param shorn True if the sheep has been shorn recently
	 * @param height Height of the sheep in inches
	 * @param weight Weight of the sheep in pounds
	 * @throws IllegalArgumentException if attributes are outside of acceptable limits
	 */
	public Sheep(int age, boolean shorn, int height, int weight) {
		if(0<=age && age<MAX_AGE) {
			this.age = age;
		} else {
			throw new IllegalArgumentException("Illegal Argument: age must be between 0 and " 
					+ MAX_AGE);
		}
		this.shornRecently = shorn;
		if(MIN_HEIGHT<=height && height<MAX_HEIGHT) {
			this.heightInInches = height;
		} else {
			throw new IllegalArgumentException("Illegal Argument: height must be between " 
					+ MIN_HEIGHT + " and " + MAX_HEIGHT);
		}
		if(MIN_WEIGHT<=weight && weight<MAX_WEIGHT) {
			this.weightInPounds = weight;
		} else {
			throw new IllegalArgumentException("Illegal Argument: weight must be between "
					+ MIN_WEIGHT + " and " + MAX_WEIGHT);
		}
	}
	
	/**
	 * The string representation of a sheep.
	 * @return String representation of the object
	 */
	public String toString() {
		return "A " + (shornRecently ? "recently shorn, " : "") + age + " year old, " 
			+ heightInInches + " inch tall sheep weighing " + weightInPounds + " pounds";
	}
	
	@Override
	/**
	 * Cause object to vocalize (make its sound).
	 */
	public void vocalize() {
		WavPlayer player = new WavPlayer("baa.wav");
		player.play();
	}

}
